==> qcanvas_backend-0.1.10a3.tar.gz: qcanvas_backend-0.1.10a3/qcanvas_backend/task_master/task_master.py <==
import logging
from abc import abstractmethod, ABC
from typing import *

from qcanvas_backend.task_master.task_id import TaskID

_logger = logging.getLogger(__name__)


class Reporter:
    def __init__(self, goal_name: str, step_name: str):
        self.task_master: Optional["TaskMaster"] = None
        self.task_id = TaskID(goal_name, step_name)

    def ensure_task_master_assigned(self) -> None:
        if self.task_master is None:
            raise Exception("Reporter has not been assigned to any task master yet")

    def failed(self, context: str | Exception) -> None:
        self.ensure_task_master_assigned()
        self.task_master.report_failed(self.task_id, context)

    def progress(self, task_id: TaskID, current: int, total: int) -> None:
        self.ensure_task_master_assigned()
        assert current <= total
        self.task_master.report_progress(task_id, current, total)


T = TypeVar("T", bound=Reporter)


class TaskMaster(ABC):
    @abstractmethod
    def report_failed(self, task_id: TaskID, context: str | Exception) -> None: ...

    @abstractmethod
    def report_progress(self, task_id: TaskID, current: int, total: int) -> None:
        """
        Implementations can expect:
        - TaskID for a specific task to always be the same
        - For intermediate tasks to be reported as (current=0, total=0)
        - For total to change as the task progresses
        - For finished tasks to be reported as current = total (unless total = 0, in which case it is an intermediate task)
        :param task_id:
        :param current:
        :param total:
        :return:
        """

    def accept(self, reporter: T) -> T:
        reporter.task_master = self
        return reporter

==> qcanvas_backend-0.2.3.tar.gz: qcanvas_backend-0.2.3/qcanvas_backend/task_master/task_master.py <==
import logging
from abc import ABC, abstractmethod
from typing import *

from qcanvas_backend.task_master.task_id import TaskID

_logger = logging.getLogger(__name__)


class Reporter:
    def __init__(self, goal_name: str, step_name: str):
        self.task_master: Optional["TaskMaster"] = None
        self.task_id = TaskID(goal_name, step_name)

    def ensure_task_master_assigned(self) -> None:
        if self.task_master is None:
            raise Exception("Reporter has not been assigned to any task master yet")

    def failed(self, context: str | Exception) -> None:
        self.ensure_task_master_assigned()
        self.task_master.report_failed(self.task_id, context)

    def progress(self, current: int, total: int) -> None:
        self.ensure_task_master_assigned()
        assert current <= total
        self.task_master.report_progress(self.task_id, current, total)


T = TypeVar("T", bound=Reporter)


class TaskMaster(ABC):
    @abstractmethod
    def report_failed(self, task_id: TaskID, context: str | Exception) -> None: ...

    @abstractmethod
    def report_progress(self, task_id: TaskID, current: int, total: int) -> None:
        """
        Implementations can expect:
        - TaskID for a specific task to always be the same
        - For intermediate tasks to be reported as (current=0, total=0)
        - For total to change as the task progresses
        - For finished tasks to be reported as current = total (unless total = 0, in which case it is an intermediate task)
        :param task_id:
        :param current:
        :param total:
        :return:
        """

    def accept(self, reporter: T) -> T:
        reporter.task_master = self
        return reporter
